/* src/math1/gnmlib/rgnge.f -- translated by f2c (version 20020621).
   You must link the resulting object file with the libraries:
	-lf2c -lm   (in that order)
*/

#include "libtinyf2c.h"

/* Table of constant values */

static integer c__10 = 10;

/* ----------------------------------------------------------------------- */
/*     RGNGE */
/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
doublereal rgnge_(real *rx)
{
    /* System generated locals */
    real ret_val;

    /* Local variables */
    static integer ip;
    static real bx;
    extern /* Subroutine */ int gnge_(real *, real *, integer *);
    extern doublereal rexp_(real *, integer *, integer *);

    gnge_(rx, &bx, &ip);
    ret_val = rexp_(&bx, &c__10, &ip);
    return ret_val;
} /* rgnge_ */

